
/*
 * slmon
 *
 * Copyright (C) 2000, 2001, 2002 Krzysztof Luks <m00se@iq.pl>
 *
 * This program is distributed under the GPL license. For details see
 * COPYING text.
 *
 * Author: Krzysztof Luks <m00se@iq.pl>
 *
 * $Date: 2004/06/20 15:56:48 $
 * $Revision: 1.2 $
 *
 */

#ifndef SLMON_RC_H
#define SLMON_RC_H

#include "defines.h"

int slmon_getconf(const struct slmon_conf conf[], const char *key);
char *slmon_strip(char *string);
char *slmon_split(char *str, char sep, int *pos);
int slmon_conf_parse(FILE * f);
int slmon_read_conf(void);

#endif
